=========
Changelog
=========

0.1.2 (26.4.2023)
------------------

* Added copyright notices to source files
* Updated pyproject.toml for automatic PyPI versioning
* Updated readme with examples and requirements
* Updated examples inside the examples folder

0.1.1 (25.4.2023)
------------------

* Updated documentation and its auto-generation
* Added pyproject.toml

0.1.0 (25.4.2023)
------------------

* First release with simple ring & locator functionality
* Documentation generation is done with Sphinx
* Pre-commit hooks to lint code when committing code to git
